@@ -1,6 +1,6 @@
 /*
     PowerDNS Versatile Database Driven Nameserver
-    Copyright (C) 2002 - 2013  PowerDNS.COM BV
+    Copyright (C) 2002 - 2016  PowerDNS.COM BV
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -20,10 +20,11 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include "logger.hh"
 #include "version.hh"
-#include "version_generated.h"
-#include <polarssl/version.h>
 
 static ProductType productType;
 
@@ -51,7 +52,7 @@ string productName() {
 
 string getPDNSVersion()
 {
-  return PDNS_VERSION;
+  return VERSION;
 }
 
 // REST API product type
@@ -67,10 +68,14 @@ string productTypeApiType() {
 
 void showProductVersion()
 {
-  theL()<<Logger::Warning<<productName()<<" "<< PDNS_VERSION <<" (" DIST_HOST ") "
-    "(C) 2001-2015 PowerDNS.COM BV" << endl;
+  theL()<<Logger::Warning<<productName()<<" "<< VERSION << " (C) 2001-2016 "
+    "PowerDNS.COM BV" << endl;
   theL()<<Logger::Warning<<"Using "<<(sizeof(unsigned long)*8)<<"-bits mode. "
-    "Built on " BUILD_DATE " by " BUILD_HOST ", "<<compilerVersion()<<"."<<endl;
+    "Built using " << compilerVersion()
+#ifndef REPRODUCIBLE
+    <<" on " __DATE__ " " __TIME__ " by " BUILD_HOST
+#endif
+    <<"."<< endl;
   theL()<<Logger::Warning<<"PowerDNS comes with ABSOLUTELY NO WARRANTY. "
     "This is free software, and you are welcome to redistribute it "
     "according to the terms of the GPL version 2." << endl;
@@ -82,15 +87,13 @@ void showBuildConfiguration()
 #ifdef HAVE_BOTAN110
     "botan1.10 " <<
 #endif
-#ifdef HAVE_BOTAN18
-    "botan1.8" <<
+#ifdef HAVE_LIBSODIUM
+    "sodium " <<
 #endif
-#ifdef HAVE_CRYPTOPP
-    "cryptopp " <<
-#endif
-#ifdef HAVE_ED25519
-    "ed25519 " <<
+#ifdef HAVE_LIBDECAF
+    "decaf " <<
 #endif
+    "openssl " <<
 #ifdef HAVE_LIBDL
     "libdl " <<
 #endif
@@ -108,15 +111,22 @@ void showBuildConfiguration()
   // Auth only
   theL()<<Logger::Warning<<"Built-in modules: "<<PDNS_MODULES<<endl;
 #endif
-#ifndef POLARSSL_SYSTEM
-  theL()<<Logger::Warning<<"Built-in PolarSSL: "<<POLARSSL_VERSION_STRING<<endl;
+#ifdef PDNS_CONFIG_ARGS
+#define double_escape(s) #s
+#define escape_quotes(s) double_escape(s)
+  theL()<<Logger::Warning<<"Configured with: "<<escape_quotes(PDNS_CONFIG_ARGS)<<endl;
+#undef escape_quotes
+#undef double_escape
 #endif
 }
 
 string fullVersionString()
 {
   ostringstream s;
-  s<<productName()<<" " PDNS_VERSION " (" DIST_HOST " built " BUILD_DATE " " BUILD_HOST ")";
+  s<<productName()<<" " VERSION;
+#ifndef REPRODUCIBLE
+  s<<" (built " __DATE__ " " __TIME__ " by " BUILD_HOST ")";
+#endif
   return s.str();
 }
 
